# This package used to be called "google-perftools", but it was renamed on 2012-02-03.

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

Name:		gperftools
Version:	2.15
Release:	1%{?dist}
License:	BSD
Group:		Development/Tools
Summary:	Very fast malloc and performance analysis tools
URL:		http://code.google.com/p/gperftools/
Source0:	https://googledrive.com/host/0B6NtGsLhIcf7MWxMMF9JdTN3UVk/%{name}-%{version}.tar.gz


Requires:	gperftools-devel = %{version}-%{release}
Requires:	pprof = %{version}-%{release}

%description
Perf Tools is a collection of performance analysis tools, including a 
high-performance multi-threaded malloc() implementation that works
particularly well with threads and STL, a thread-friendly heap-checker,
a heap profiler, and a cpu-profiler.

This is a metapackage which pulls in all of the gperftools (and pprof)
binaries, libraries, and development headers, so that you can use them.

%package devel
Summary:	Development libraries and headers for gperftools
Group:		Development/Libraries
Requires:	%{name}-libs%{?_isa} = %{version}-%{release}
Provides:	google-perftools-devel = %{version}-%{release}
Obsoletes:	google-perftools-devel < 2.0

%description devel
Libraries and headers for developing applications that use gperftools.

%package libs
Summary:	Libraries provided by gperftools
Provides:	google-perftools-libs = %{version}-%{release}
Obsoletes:	google-perftools-libs < 2.0

%description libs
Libraries provided by gperftools, including libtcmalloc and libprofiler.

%package -n pprof
Summary:	CPU and Heap Profiler tool
Requires:	graphviz
BuildArch:	noarch
Provides:	google-perftools = %{version}-%{release}
Obsoletes:	google-perftools < 2.0

%description -n pprof 
Pprof is a heap and CPU profiler tool, part of the gperftools suite.

%prep
%setup -q -n gperftools-%{name}-%{version}

# Fix end-of-line encoding
sed -i 's/\r//' README_windows.txt

# No need to have exec permissions on source code
chmod -x src/*.h src/*.cc

%build
autoreconf -i
CFLAGS=`echo $RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs -DTCMALLOC_LARGE_PAGES | sed -e 's|-fexceptions||g'`
CXXFLAGS=`echo $RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs -DTCMALLOC_LARGE_PAGES | sed -e 's|-fexceptions||g'`
%configure --disable-static --disable-libunwind

# Bad rpath!
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
# Can't build with smp_mflags
make 

%install
make DESTDIR=%{buildroot} docdir=%{_pkgdocdir}/ install
find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'

# Delete useless files
rm -rf %{buildroot}%{_pkgdocdir}/INSTALL

%check
# http://code.google.com/p/google-perftools/issues/detail?id=153
%ifnarch ppc
# Their test suite is almost always broken.
# LD_LIBRARY_PATH=./.libs make check
%endif

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files

%files -n pprof
%{_bindir}/pprof
%{_bindir}/pprof-symbolize
%{_mandir}/man1/*

%files devel
%{_pkgdocdir}/
%{_includedir}/google/
%{_includedir}/gperftools/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files libs
%{_libdir}/*.so.*

%changelog
* Fri Jan  5 2024 Ernani Azevedo <azevedo@voipdomain.io> - 2.15-1
- This release has the following bug fixes:
-
- * Xiaowei Wang has pointed out the pthread linking issue on cmake on older
-   glibcs (where -pthread is not implicit). See #1473 for more details.
- * Mikael Simberg and Tom "spot" Callaway have pointed out the missing symbols
-   issue when linking PPC or i386 builds. #1474 has all the details.
-
- Huge thanks to all contributors!

* Mon Jan  1 2024 Ernani Azevedo <azevedo@voipdomain.io> - 2.14-1
- gperftools 2.14 is out!
-
- This release has the following set of notable changes:
-
- * Roman Geissler has contributed a fix to nasty initialization bug introduced
-   in 2.13 (see github issue #1452 for one example where it fails).
- * spinlock delay support now has proper windows support. Instead of simply
-   sleeping, it uses WaitOnAddress (which is basically windows equivalent of
-   futexes). This improvement was contributed by Lennox Ho.
- * we now have basic QNX support (basic malloc + heap profiler) championed by
-   Xiang.Lin. Thanks! Do note, however, that QNX doesn't provide SIGPROF ticks,
-   so there will be no cpu profiler support on this OS.
- * Yikai Zhao has contributed several fixes to important corner cases of
-   generic_fp stacktrace method.
- * several people have contributed various improvements to our cmake build:
-   Lennox Ho, Sergey Fedorov, Mateusz Jakub Fila. But do note that cmake build
-   is still incomplete and best-effort.
- * Julian Schroeder have fixed generic_fp incompatibility with ARM pointer auth.
- * Mateusz Jakub Fila has contributed implementation of mallocinfo2 function
-   (64-bit version of mallinfo).
- * Lennox Ho has updated C malloc extension shims to include
-   {Set,Get}MemoryReleaseRate.
- * Lennox Ho has contributed the ability to disable malloc functions patching on
-   windows when TCMALLOC_DISABLE_REPLACEMENT=1 environment variable is set.
- * User poljak181 has contributed a fix to infinite recursion in some cases of
-   malloc hooks (or user-replaced operator new) and MallocExtension::instance().
- * Sergey Fedorov has contributed a fix to use MAP_ANON on some older OSes
-   without MAP_ANONYMOUS.
- * the way we detect working ucontext->pc extraction method was reworked and is
-   now fully compile-time as opposed to config-time. This means no more
-   duplication and mismatches between autoconf and cmake bits in this area.
-
- List of relevant tickets can be seen online at:
- https://github.com/gperftools/gperftools/issues?q=label%3Afixed-in-2.14+

* Mon Sep 11 2023 Ernani Azevedo <azevedo@voipdomain.io> - 2.13-1
- gperftools 2.13 is out!
-
- This release includes a few minor fixes:
-
- * Ivan Dlugos has fixed some issues with cmake and config.h defines.
- * 32-bit builds no longer require 64-bit atomics (which we wrongly introduced
-   in 2.11 and which broke builds on some 32-bit architectures).
- * generic_fp backtracing method now uses robust address probing method. The
-   previous approach had occasional false positives, which caused occasional
-   rare crashes.
- * In some cases, MSVC generated TrivialOnce machine code that deadlocked
-   programs on startup. The issue is now fixed.

* Thu Aug 24 2023 Ernani Azevedo <azevedo@voipdomain.io> - 2.12-1
- Brett T. Warden contributed one significant fix. After a change in the previous
- release, we installed broken pkg-config files. Brett noticed and fixed that.
- Huge thanks!

* Mon Aug 14 2023 Ernani Azevedo <azevedo@voipdomain.io> - 2.11-1
- gperftools 2.11 is out!
-
- Most notable change is that Linux/aarch64 and Linux/riscv are now fully
- supported. That is, all unit tests pass on those architectures (previously the
- heap leak checker was broken).
-
- Also notable is that heap leak checker support is officially deprecated as of
- this release. All bug fixes from now are on a best effort basis. For clarity we
- also declare that it is only expected to work (for some definition of work) on
- Linux/x86 (all kinds), Linux/aarch64, Linux/arm, Linux/ppc (untested as of this
- writing) and Linux/mips (untested as well). While some functionality worked in
- the past on BSDs, it was never fully functional; and will never be. We strongly
- recommend everyone to switch to asan and friends.
-
- For major internal changes it is also worth mentioning that we now fully
- switched to C++-11 std::atomic. All custom OS- and arch-specific atomic bits
- have been removed at last.
-
- Another notable change is that mmap and sbrk hooks facility is now no-op. We
- keep API and ABI for formal compatibility, but the calls to add mmap/sbrk hooks
- do nothing and return an error (whenever possible as part of API). There seem
- to be no users of it anyways, and mmap replacement API that is part of that
- facility really screwed up 64-bit offsets on (some/most) 32-bit systems.
- Internally for heap profiler and heap checker we have a new, but non-public API
- (see mmap_hook.h).
-
- Most tests now pass on NetBSD x86-64 (I tested on version 9.2). And only one
- that fails is new stacktrace test for stacktraces from signal handler (so there
- could be some imperfections for cpu profiles).
-
- We don't warn people away from the libgcc stacktrace capturing method anymore.
- In fact users on most recent glibc-s are advised to use it (pass
- --enable-libgcc-unwinder-by-default). This is thanks to the dl_find_object API
- offered by glibc which allows this implementation to be fully
- async-signal-safe. Modern Linux distros should from now on build their
- gperftools package with this enabled (other than those built on top of musl).
-
- generic_fp and generic_fp_unsafe stacktrace capturing methods have been
- expanded for more architectures and even some basic non-Linux support. We have
- completely removed old x86-specific frame pointer stacktrace implementation in
- favor of those 2. _unsafe one should be roughly equivalent to the old x86
- method. And 'safe' one is recommended as a new default for those who want
- FP-based stacktracing. Safe implementation robustly checks memory before
- accessing it, preventing unlikely, but not impossible crashes when frame
- pointers are bogus.
-
- On platforms that support it, we now build gperftools with
- "-fno-omit-frame-pointer -momit-leaf-frame-pointer". This makes gperftools
- mostly frame-pointer-ful, but without performance hit in places that matter
- (this is how Google builds their binaries BTW). That should cover gcc (at
- least) on x86, aarch64 and riscv. Intention for this change is to make
- distro-shipped libtcmalloc.so compatible with frame-pointer stacktrace
- capturing (for those who still do heap profiling, for example). Of course,
- passing --enable-frame-pointers still gives you full frame pointers (i.e. even
- for leaf functions).
-
- There is now support for detecting actual page size at runtime. tcmalloc will
- now allocate memory in units of this page size. It particularly helps on arms
- with 64k pages to return memory back to the kernel. But it is somewhat
- controversial, because it effectively bumps tcmalloc logical page size on those
- machines potentially increasing fragmentation. In any case, there is now a new
- environment variable TCMALLOC_OVERRIDE_PAGESIZE allowing people to override
- this check. I.e. to either reduce effective page size down to tcmalloc's
- logical page size or to increase it.
-
- MallocExtension::MarkThreadTemporarilyIdle has been changed to be identical to
- MarkThreadIdle. MarkThreadTemporarilyIdle is believed to be unused, anyways.
- See issue #880 for details.
-
- There are a whole bunch of smaller fixes. Many of those smaller fixes had no
- associated ticket, but some had. People are advised to see here for list of
- notable tickets closed in this release:
- https://github.com/gperftools/gperftools/issues?q=label%3Afixed-in-2.11+
-
- Some of those tickets are quite notable (fixes for rare deadlocks in cpu
- profiler ProfilerStop or while capturing heap growth stacktraces (aka
- growthz)).
-
- Here is list of notable contributions:
-
- * Chris Cambly has contributed initial support for AIX
- * Ali Saidi has contributed SpinlockPause implementation for aarch64
- * Henrik Reinstädtler has contributed fix for cpuprofiler on aarch64 OSX
- * Gabriel Marin has backported Chromium's commit for always sanity checking
-   large frees
- * User zhangyiru has contributed a fix to report the number of leaked bytes as
-   size_t instead of (usually 32-bit) int.
- * Sergey Fedorov has contributed some fix for building on older ppc-based
-   OSX-es
- * User tigeran has removed unused using declaration
- * Artem Polyakov has contributed auto-detection of several MPI systems w.r.t.
-   filenames used by HEAPPROFILE and CPUPROFILE environment variables. Also, we
-   now support HEAPPROFILE_USE_PID and CPUPROFILE_USE_PID environment variables
-   that force profile filenames to have pid appended. Which will be useful for
-   some programs that fork for parallelism. See #1263 for details.
- * Ken Raffenetti has extended MPI detection mentioned above with detection of
-   MPICH system.
-
- Thanks a lot!

* Mon May 30 2022 Ernani Azevedo <azevedo@voipdomain.io> - 2.10-1
- gperftools 2.10 is out!
-
- Here are notable changes:
-
- * Matt T. Proud contributed documentation fix to call Go programming language
-   by it's true name instead of golang.
- * Robert Scott contributed debugallocator feature to use readable (PROT_READ)
-   fence pages. This is activated by TCMALLOC_PAGE_FENCE_READABLE environment
-   veriable.
- * User stdpain contributed fix for cmake detection of libunwind.
- * Natale Patriciello contributed fix for OSX Monterey support.
- * Volodymyr Nikolaichuk contributed support for returning memory back to OS by
-   using mmap with MAP_FIXED and PROT_NONE. It is off by default and enabled by
-   preprocessor define: FREE_MMAP_PROT_NONE. This should help OSes that don't
-   support Linux-style madvise MADV_DONTNEED or BSD-style MADV_FREE.
- * Jingyun Hua has contributed basic support for LoongArch.
- * Github issue #1338 of failing to build on some recent musl versions has been
-   fixed.
- * Github issue #1321 of failing to ship cmake bits with .tar.gz archive has
-   been fixed.

* Wed Mar  3 2021 Ernani Azevedo <azevedo@voipdomain.io> - 2.9.1-1
- gperftools 2.9.1 is out!
-
- Minor fixes landed since previous release:
-
- * OSX builds now prefer backtrace() and have somewhat working heap sampling.
- * Incorrect assertion failure was fixed that crashed tcmalloc if assertions
-   were on and sized delete was used. More details in github issue #1254.

* Sun Feb 21 2021 Ernani Azevedo <azevedo@voipdomain.io> - 2.9-1
- gperftools 2.9 is out!
-
- Here are notable changes:
-
- * Jarno Rajahalme has contributed fix crashing bug in syscalls support for
-   aarch64.
- * User SSE4 has contributed basic support for Elbrus 2000 architecture (!)
- * Venkatesh Srinivas has contributed cleanup to atomic ops.
- * Đoàn Trần Công Danh has fixed cpu profiler compilation on musl.
- * there is now better backtracing support for aarch64 and riscv. x86-64 with
-   frame pointers now also defaults to this new "generic" frame pointer
-   backtracer.
- * emergency malloc is now enabled by default. Fixes hang on musl when libgcc
-   backtracer is enabled.
- * bunch of legacy config tests has been removed
- * Venkatesh Srinivas has contributed thread-safety annotations support.
- * couple more unit test bugs that caused tcmalloc_unittest to fail on recent
-   clang has been fixed.
- * usage of unsupportable linux_syscall_support.h has been removed from few
-   places. Building with --disable-heap-checker now completely avoids it. Expect
-   complete death of this header in next major release.

* Mon Dec 21 2020 Ernani Azevedo <azevedo@voipdomain.io> - 2.8.1-1
- gperftools-2.8.1 is out!
-
- Here are notable changes:
-
- * previous release contained change to release memory without page heap lock,
-   but this change had at least one bug that caused to crashes and corruption
-   when running under aggressive decommit mode (this is not default). While we
-   check for other bugs, this feature was reverted. See github issue #1204 and
-   issue #1227.
- * stack traces depth captured by gperftools is now up to 254 levels deep.
-   Thanks to Kerrick Staley for this small but useful tweak.
- * Levon Ter-Grigoryan has contributed small fix for compiler warning.
- * Grant Henke has contributed updated detection of program counter register for
-   OS X on arm64.
- * Tim Gates has contributed small typo fix.
- * Steve Langasek has contributed basic build fixes for riscv64.
- * Isaac Hier and okhowang have contributed premiliminary port of build
-   infrastructure to cmake. This works, but it is very premiliminary.
-   Autotools-based build is the only officially supported build for now.

* Mon Jul  6 2020 Ernani Azevedo <azevedo@voipdomain.io> - 2.8-1
- gperftools 2.8 is out!
-
- Here are notable changes:
-
- * ProfilerGetStackTrace is now officially supported API for libprofiler.
-   Contributed by Kirill Müller.
- * Build failures on mingw were fixed. This fixed issue #1108.
- * Build failure of page_heap_test on MSVC was fixed.
- * Ryan Macnak contributed fix for compiling linux syscall support on i386 and
-   recent GCCs. This fixed issue #1076.
- * test failures caused by new gcc 10 optimizations were fixed. Same change also
-   fixed tests on clang.

* Mon Apr 30 2018 Ernani Azevedo <azevedo@voipdomain.io> - 2.7-1
- gperftools 2.7 is out!
-
- Few people contributed minor, but important fixes since rc.
-
- Changes:
-
- * bug in span stats printing introduced by new scalable page heap change was
-   fixed.
- * Christoph Müllner has contributed couple warnings fixes and initial support
-   for aarch64_ilp32 architecture.
- * Ben Dang contributed documentation fix for heap checker.
- * Fabrice Fontaine contributed fixed for linking benchmarks with
-   --disable-static.
- * Holy Wu has added sized deallocation unit tests.
- * Holy Wu has enabled support of sized deallocation (c++14) on recent MSVC.
- * Holy Wu has fixed MSVC build in WIN32_OVERRIDE_ALLOCATORS mode. This closed
-   issue #716.
- * Holy Wu has contributed cleanup of config.h used on windows.
- * Mao Huang has contributed couple simple tcmalloc changes from chromium code
-   base. Making our tcmalloc forks a tiny bit closer.
- * issue #946 that caused compilation failures on some Linux clang installations
-   has been fixed. Much thanks to github user htuch for helping to diagnose
-   issue and proposing a fix.
- * Tulio Magno Quites Machado Filho has contributed build-time fix for PPC (for
-   problem introduced in one of commits since RC).

* Sat Dec  9 2017 Ernani Azevedo <azevedo@voipdomain.io> - 2.6.3-1
- gperftools 2.6.3 is out!
-
- Just two fixes were made in this release:
-
- * Stephan Zuercher has contributed a build fix for some recent XCode versions.
-   See issue #942 for more details.
- * assertion failure on some windows builds introduced by 2.6.2 was fixed.
-   Thanks to github user nkeemik for reporting it and testing fix. See issue
-   #944 for more details.

* Thu Nov 30 2017 Ernani Azevedo <azevedo@voipdomain.io> - 2.6.2-1
- gperftools 2.6.2 is out!
-
- Most notable change is recently added support for C++17 over-aligned allocation
- operators contributed by Andrey Semashev. I've extended his implementation to
- have roughly same performance as malloc/new. This release also has native
- support for C11 aligned_alloc.
-
- Rest is mostly bug fixes:
-
- * Jianbo Yang has contributed a fix for potentially severe data raceintroduced
-   by malloc fast-path work in gperftools 2.6. This race could cause occasional
-   violation of total thread cache size constraint. See issue #929 for more
-   details.
- * Correct behavior in out-of-memory condition in fast-path cases was restored.
-   This was another bug introduced by fast-path optimization in gperftools 2.6
-   which caused operator new to silently return NULL instead of doing correct
-   C++ OOM handling (calling new_handler and throwing bad_alloc).
- * Khem Raj has contributed couple build fixes for newer glibcs (ucontext_t vs
-   struct ucontext and loff_t definition)
- * Piotr Sikora has contributed build fix for OSX (not building unwind
-   benchmark). This was issue #910 (thanks to Yuriy Solovyov for reporting it).
- * Dorin Lazăr has contributed fix for compiler warning
- * issue #912 (occasional deadlocking calling getenv too early on windows) was
-   fixed. Thanks to github user shangcangriluo for reporting it.
- * Couple earlier lsan-related commits still causing occasional issues linking
-   on OSX has been reverted. See issue #901.
- * Volodimir Krylov has contributed GetProgramInvocationName for FreeBSD
- * changsu lee has contributed couple minor correctness fixes (missing va_end()
-   and missing free() call in rarely executed Symbolize path)
- * Andrew C. Morrow has contributed some more page heap stats. See issue #935.
- * some cases of built-time warnings from various gcc/clang versions about
-   throw() declarations have been fixes.

* Thu Oct 12 2017 Miroslav Rezanina <mrezanin@redhat.com> - 2.4-8.el7
- Rebase to 2.6.1 [bz#1431240]
- Removed libunwind usage [bz#1467203]
- Resolves: bz#1431240 
  (gperftools fails to build on s390x, lacks s390x support)
- Resolves: bz#1467203
  (Please, remove libunwind from the gperftools-libs (and 389-ds-base) requirements)

* Wed Jun 22 2016 Miroslav Rezanina <mrezanin@redhat.com> - 2.4-8.el7
- gp-Use-initial-exec-tls-for-libunwind-s-recursion-flag.patch [bz#1339710]
- Resolves: bz#1339710
  (initalization of 'recursive' tls variable in libunwind stack capturer occasionally triggers deadlock in ceph)

* Wed Aug 26 2015 Miroslav Rezanina <mrezanin@redhat.com> 2.4-7
- Rebuild to fix NVR [bz#1269032]
- Resolves: bz#1269032
  (gperftools NVR lower than EPEL version)

* Wed Aug 26 2015 Miroslav Rezanina <mrezanin@redhat.com> 2.4-2
- gperf-allow-customizing-trace-filename.patch [bz#1232702]
- Resolves: bz#1232702
  (gperftools: tcmalloc debug version uses hard-coded path /tmp/google.alloc) 

* Tue Jun 02 2015 Miroslav Rezanina <mrezanin@redhat.com> 2.4-1
- Import to RHEL
